@@ -9,13 +9,11 @@ import asgi_lifespan
 import httpx
 import pytest
 from fastapi import FastAPI
-from fief_client import Fief
 from sqlalchemy import engine
 from sqlalchemy_utils import create_database, drop_database
 
 from fief.apps import admin_app, auth_app
 from fief.crypto.access_token import generate_access_token
-from fief.crypto.id_token import get_user_claims
 from fief.crypto.token import generate_token
 from fief.csrf import check_csrf
 from fief.db import AsyncConnection, AsyncEngine, AsyncSession
@@ -24,7 +22,7 @@ from fief.db.main import get_main_async_session
 from fief.db.types import DatabaseType, get_driver
 from fief.db.workspace import get_connection
 from fief.dependencies.current_workspace import get_current_workspace_session
-from fief.dependencies.fief import get_fief
+from fief.dependencies.fief import FiefAsyncRelativeEndpoints, get_fief
 from fief.dependencies.tasks import get_send_task
 from fief.dependencies.workspace_creation import get_workspace_creation
 from fief.dependencies.workspace_db import get_workspace_db
@@ -32,10 +30,10 @@ from fief.models import (
     AdminAPIKey,
     AdminSessionToken,
     MainBase,
+    User,
     Workspace,
     WorkspaceUser,
 )
-from fief.schemas.user import UserDB
 from fief.services.workspace_creation import WorkspaceCreation
 from fief.services.workspace_db import WorkspaceDatabase
 from fief.settings import settings
@@ -221,7 +219,7 @@ async def workspace_creation_mock() -> MagicMock:
 
 @pytest.fixture
 async def fief_client_mock() -> MagicMock:
-    return MagicMock(spec=Fief)
+    return MagicMock(spec=FiefAsyncRelativeEndpoints)
 
 
 @pytest.fixture
@@ -240,9 +238,12 @@ def workspace_host(
 
 
 @pytest.fixture
-def workspace_admin_user() -> UserDB:
-    return UserDB(
-        email="dev@bretagne.duchy", hashed_password="dev", tenant_id=uuid.uuid4()
+def workspace_admin_user() -> User:
+    return User(
+        id=uuid.uuid4(),
+        email="dev@bretagne.duchy",
+        hashed_password="dev",
+        tenant_id=uuid.uuid4(),
     )
 
 
@@ -250,7 +251,7 @@ def workspace_admin_user() -> UserDB:
 async def admin_session_token(
     main_session: AsyncSession,
     workspace: Workspace,
-    workspace_admin_user: UserDB,
+    workspace_admin_user: User,
 ) -> AsyncGenerator[Tuple[AdminSessionToken, str], None]:
     workspace_user = WorkspaceUser(
         workspace_id=workspace.id, user_id=workspace_admin_user.id
@@ -262,7 +263,7 @@ async def admin_session_token(
     session_token = AdminSessionToken(
         token=token_hash,
         raw_tokens="{}",
-        raw_userinfo=json.dumps(get_user_claims(workspace_admin_user)),
+        raw_userinfo=json.dumps(workspace_admin_user.get_claims()),
     )
     main_session.add(session_token)
 
@@ -369,7 +370,7 @@ def access_token(
             user_tenant.get_sign_jwk(),
             user_tenant.get_host(workspace.domain),
             client,
-            UserDB.from_orm(user),
+            user,
             ["openid"],
             3600,
         )
