@@ -6,7 +6,6 @@ from fief.dependencies.pagination import PaginatedObjects
 from fief.dependencies.workspace import get_paginated_workspaces
 from fief.dependencies.workspace_creation import get_workspace_creation
 from fief.dependencies.workspace_db import get_workspace_db
-from fief.errors import APIErrorCode
 from fief.models import AdminSessionToken, Workspace
 from fief.schemas.generics import PaginatedResults
 from fief.schemas.workspace import (
@@ -76,7 +75,7 @@ async def create_workspace(
     except WorkspaceDatabaseConnectionError as e:
         raise HTTPException(
             status_code=status.HTTP_400_BAD_REQUEST,
-            detail=APIErrorCode.WORKSPACE_DB_CONNECTION_ERROR,
+            detail=e.message,
         ) from e
 
     return WorkspacePublic.from_orm(workspace)
