@@ -35,10 +35,13 @@ class Settings(BaseSettings):
     sentry_dsn: Optional[str] = None
     root_domain: str = "localhost:8000"
     allow_origin_regex: str = "http://.*localhost:[0-9]+"
+    port: int = 8000
 
     secret: SecretStr
     encryption_key: bytes
 
+    generated_jwk_size: int = 4096
+
     database_type: DatabaseType = DatabaseType.SQLITE
     database_url: Optional[str] = None
     database_host: Optional[str] = None
@@ -73,7 +76,6 @@ class Settings(BaseSettings):
     refresh_token_lifetime_seconds: int = 3600 * 24 * 30
 
     fief_domain: str = "localhost:8000"
-    fief_base_url: str = "http://localhost:8000"
     fief_client_id: str
     fief_client_secret: str
     fief_encryption_key: Optional[str] = None
