@@ -2,9 +2,6 @@ import uuid
 
 import dramatiq
 
-from fief.db.main import main_async_session_maker
-from fief.db.workspace import get_workspace_session
-from fief.settings import settings
 from fief.tasks.base import TaskBase
 
 
@@ -28,8 +25,4 @@ class OnAfterRegisterTask(TaskBase):
         )
 
 
-on_after_register = dramatiq.actor(
-    OnAfterRegisterTask(
-        main_async_session_maker, get_workspace_session, settings.get_email_provider()
-    )
-)
+on_after_register = dramatiq.actor(OnAfterRegisterTask())
